@@ -3,10 +3,7 @@ from redisbench_admin.export.common.common import (
     get_kv_tags,
     prepare_tags,
     get_timeserie_name,
-    add_datapoint,
-)
-from redisbench_admin.export.ftsb_redisearch.ftsb_redisearch_json_format import (
-    get_metric_detail,
+    add_datapoint, get_metric_detail,
 )
 from redisbench_admin.export.redis_benchmark.metrics_definition import (
     redis_benchmark_metrics_definition,
@@ -52,7 +49,7 @@ def fill_tags_from_passed_array(extra_tags_array):
 
 
 def redis_benchmark_export_logic(
-    benchmark_result, extra_tags_array, results_type, time_series_dict, use_result
+        benchmark_result, extra_tags_array, results_type, time_series_dict, use_result
 ):
     ok = True
     start_time_ms = get_tag_fromextra_tags_array(extra_tags_array, "start_time_ms")
