@@ -1,11 +1,10 @@
 import csv
 import datetime as dt
 import json
+import logging
 import operator
 import os
 import os.path
-import subprocess
-import sys
 import tarfile
 from functools import reduce
 from zipfile import ZipFile
@@ -36,7 +35,7 @@ def upload_artifacts_to_s3(artifacts, s3_bucket_name, s3_bucket_path):
 def whereis(program):
     for path in os.environ.get("PATH", "").split(":"):
         if os.path.exists(os.path.join(path, program)) and not os.path.isdir(
-            os.path.join(path, program)
+                os.path.join(path, program)
         ):
             return os.path.join(path, program)
     return None
@@ -52,20 +51,33 @@ def required_utilities(utility_list):
     return result
 
 
-def decompress_file(compressed_filename, uncompressed_filename):
+def decompress_file(compressed_filename:str, path=None):
+    uncompressed_filename = compressed_filename
+    logging.warning(
+        "Decompressing {}...".format(compressed_filename))
     if compressed_filename.endswith(".zip"):
         with ZipFile(compressed_filename, "r") as zipObj:
-            zipObj.extractall()
+            zipObj.extractall(path)
+            suffix=".zip"
+        uncompressed_filename = compressed_filename[:-len(suffix)]
 
-    elif compressed_filename.endswith("tar.gz"):
+    elif compressed_filename.endswith(".tar.gz"):
         tar = tarfile.open(compressed_filename, "r:gz")
-        tar.extractall()
+        tar.extractall(path)
         tar.close()
+        suffix = ".tar.gz"
+        uncompressed_filename = compressed_filename[:-len(suffix)]
 
-    elif compressed_filename.endswith("tar"):
+    elif compressed_filename.endswith(".tar"):
         tar = tarfile.open(compressed_filename, "r:")
-        tar.extractall()
+        tar.extractall(path)
         tar.close()
+        suffix = ".tar"
+        uncompressed_filename = compressed_filename[:-len(suffix)]
+    else:
+        logging.warning(
+            "Filename {} was not in a supported compression extension [zip|tar.gz|tar]".format(compressed_filename))
+    return uncompressed_filename
 
 
 def findJsonPath(element, json):
@@ -77,7 +89,7 @@ def ts_milli(at_dt):
 
 
 def retrieve_local_or_remote_input_json(
-    config_filename, local_path, option_name, format="json", csv_header=False
+        config_filename, local_path, option_name, format="json", csv_header=False
 ):
     benchmark_config = {}
 
@@ -89,7 +101,7 @@ def retrieve_local_or_remote_input_json(
         )
         r = requests.get(config_filename)
         benchmark_config[config_filename] = r.json()
-        remote_filename = config_filename[config_filename.rfind("/") + 1 :]
+        remote_filename = config_filename[config_filename.rfind("/") + 1:]
         local_config_file = "{}/{}".format(local_path, remote_filename)
         open(local_config_file, "wb").write(r.content)
         print(
@@ -134,7 +146,7 @@ def retrieve_local_or_remote_input_json(
 
 
 def read_json_or_csv(
-    benchmark_config, config_filename, format, local_file, csv_has_header
+        benchmark_config, config_filename, format, local_file, csv_has_header
 ):
     if format == "json":
         benchmark_config[config_filename] = json.load(local_file)
